@@ -24,14 +24,10 @@ use crate::{context::Context, relay::socks5::Address, ServerAddr};
 use super::{
     is_dual_stack_addr,
     sys::{
-        create_inbound_tcp_socket,
-        set_common_sockopt_after_accept,
-        set_tcp_fastopen,
-        socket_bind_dual_stack,
+        create_inbound_tcp_socket, set_common_sockopt_after_accept, set_tcp_fastopen, socket_bind_dual_stack,
         TcpStream as SysTcpStream,
     },
-    AcceptOpts,
-    ConnectOpts,
+    AcceptOpts, ConnectOpts,
 };
 
 /// TcpStream for outbound connections
