@@ -24,12 +24,7 @@ use shadowsocks_service::shadowsocks::relay::socks5::Address;
 use shadowsocks_service::{
     acl::AccessControl,
     config::{
-        read_variable_field_value,
-        Config,
-        ConfigType,
-        LocalConfig,
-        LocalInstanceConfig,
-        ProtocolType,
+        read_variable_field_value, Config, ConfigType, LocalConfig, LocalInstanceConfig, ProtocolType,
         ServerInstanceConfig,
     },
     local::{loadbalancing::PingBalancer, Server},
@@ -44,8 +39,7 @@ use shadowsocks_service::{
 use crate::logging;
 use crate::{
     config::{Config as ServiceConfig, RuntimeMode},
-    monitor,
-    vparser,
+    monitor, vparser,
 };
 
 #[cfg(feature = "local-dns")]
@@ -137,6 +131,14 @@ pub fn define_command_line_options(mut app: Command) -> Command {
             .value_parser(vparser::parse_server_addr)
             .help("UDP relay's bind address, default is the same as local-addr"),
     )
+    .arg(
+        Arg::new("UDP_ASSOCIATE_ADDR")
+        .long("udp-associate-addr")
+        .num_args(1)
+        .action(ArgAction::Set)
+        .value_parser(vparser::parse_server_addr)
+        .help("UDP relay's externally visible address return in UDP Associate responses"),
+    )
     .arg(
         Arg::new("SERVER_ADDR")
             .short('s')
@@ -737,6 +739,10 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
                 local_config.udp_addr = Some(udp_bind_addr);
             }
 
+            if let Some(udp_associate_addr) = matches.get_one::<ServerAddr>("UDP_ASSOCIATE_ADDR").cloned() {
+                local_config.udp_associate_addr = Some(udp_associate_addr);
+            }
+
             #[cfg(feature = "local-tunnel")]
             if let Some(addr) = matches.get_one::<Address>("FORWARD_ADDR").cloned() {
                 local_config.forward_addr = Some(addr);
